==> paraview-v1.0.4.zip: paraview-v1.0.4/ParaView/Widgets/vtkKWSimpleEntryDialog.h <==
/*=========================================================================

Copyright (c) 1998-2003 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkKWSimpleEntryDialog - a message dialog with a single entry superclass

#ifndef __vtkKWSimpleEntryDialog_h
#define __vtkKWSimpleEntryDialog_h

#include "vtkKWMessageDialog.h"

class vtkKWApplication;
class vtkKWLabeledEntry;

class VTK_EXPORT vtkKWSimpleEntryDialog : public vtkKWMessageDialog
{
public:
  static vtkKWSimpleEntryDialog* New();
  vtkTypeRevisionMacro(vtkKWSimpleEntryDialog, vtkKWMessageDialog);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Create the widget
  virtual void Create(vtkKWApplication *app, const char *args);

  // Description:
  // Access to the entry
  vtkGetObjectMacro(Entry, vtkKWLabeledEntry);

protected:
  vtkKWSimpleEntryDialog();
  ~vtkKWSimpleEntryDialog();

  vtkKWLabeledEntry *Entry;

private:
  vtkKWSimpleEntryDialog(const vtkKWSimpleEntryDialog&); // Not implemented
  void operator=(const vtkKWSimpleEntryDialog&); // Not implemented
};


#endif

==> paraview-v1.2.1.zip: paraview-v1.2.1/ParaView/Widgets/vtkKWSimpleEntryDialog.h <==
/*=========================================================================

  Module:    vtkKWSimpleEntryDialog.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkKWSimpleEntryDialog - a message dialog with a single entry superclass

#ifndef __vtkKWSimpleEntryDialog_h
#define __vtkKWSimpleEntryDialog_h

#include "vtkKWMessageDialog.h"

class vtkKWApplication;
class vtkKWLabeledEntry;

class VTK_EXPORT vtkKWSimpleEntryDialog : public vtkKWMessageDialog
{
public:
  static vtkKWSimpleEntryDialog* New();
  vtkTypeRevisionMacro(vtkKWSimpleEntryDialog, vtkKWMessageDialog);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Create the widget
  virtual void Create(vtkKWApplication *app, const char *args);

  // Description:
  // Access to the entry
  vtkGetObjectMacro(Entry, vtkKWLabeledEntry);

  // Description:
  // Invoke the dialog and display it in a modal manner. 
  // This method returns a zero if the dilaog was killed or 
  // canceled, nonzero otherwise.
  virtual int Invoke();

protected:
  vtkKWSimpleEntryDialog();
  ~vtkKWSimpleEntryDialog();

  vtkKWLabeledEntry *Entry;

private:
  vtkKWSimpleEntryDialog(const vtkKWSimpleEntryDialog&); // Not implemented
  void operator=(const vtkKWSimpleEntryDialog&); // Not implemented
};


#endif
